@@ -175,7 +175,7 @@ class TinyDBRepository(Repository):
             entity_data: Dictionary with the attributes of the entity.
         """
         entity_data = entity.dict()
-        entity_data["model_type_"] = entity._model_name.lower()
+        entity_data["model_type_"] = entity.model_name.lower()
 
         return entity_data
 
@@ -184,14 +184,14 @@ class TinyDBRepository(Repository):
         for entity in self.staged["add"]:
             self.db_.upsert(
                 self._export_entity(entity),
-                (Query().model_type_ == entity._model_name.lower())
+                (Query().model_type_ == entity.model_name.lower())
                 & (Query().id_ == entity.id_),
             )
         self.staged["add"].clear()
 
         for entity in self.staged["remove"]:
             self.db_.remove(
-                (Query().model_type_ == entity._model_name.lower())
+                (Query().model_type_ == entity.model_name.lower())
                 & (Query().id_ == entity.id_)
             )
         self.staged["remove"].clear()
